@@ -10,10 +10,14 @@
 
 #include "backends/linkprovider.h"
 #include "core_debug.h"
+#include "daemon.h"
 #include "kdeconnectconfig.h"
 #include "lanlinkprovider.h"
 #include "plugins/share/shareplugin.h"
 
+// This is a huge size for a single packet, but I'm being conservative given there wasn't a limit before and I don't want to break things
+static const int MAX_PACKET_SIZE = 32 * 1024 * 1024;
+
 LanDeviceLink::LanDeviceLink(const DeviceInfo &deviceInfo, LanLinkProvider *parent, QSslSocket *socket)
     : DeviceLink(deviceInfo.id, parent)
     , m_socket(nullptr)
@@ -56,9 +60,15 @@ QHostAddress LanDeviceLink::hostAddress() const
 bool LanDeviceLink::sendPacket(NetworkPacket &np)
 {
     if (np.payload()) {
+        Device *device = Daemon::instance()->getDevice(deviceId());
+        if (device == nullptr) {
+            qCWarning(KDECONNECT_CORE) << "Device disconnected" << deviceId();
+            return false;
+        }
+        // FIXME: Remove packet-type-specific logic from the link
         if (np.type() == PACKET_TYPE_SHARE_REQUEST && np.payloadSize() >= 0) {
             if (!m_compositeUploadJob || !m_compositeUploadJob->isRunning()) {
-                m_compositeUploadJob = new CompositeUploadJob(deviceId(), true);
+                m_compositeUploadJob = new CompositeUploadJob(device, true);
             }
 
             m_compositeUploadJob->addSubjob(new UploadJob(np));
@@ -67,7 +77,7 @@ bool LanDeviceLink::sendPacket(NetworkPacket &np)
                 m_compositeUploadJob->start();
             }
         } else { // Infinite stream
-            CompositeUploadJob *fireAndForgetJob = new CompositeUploadJob(deviceId(), false);
+            CompositeUploadJob *fireAndForgetJob = new CompositeUploadJob(device, false);
             fireAndForgetJob->addSubjob(new UploadJob(np));
             fireAndForgetJob->start();
         }
@@ -85,10 +95,18 @@ bool LanDeviceLink::sendPacket(NetworkPacket &np)
 
 void LanDeviceLink::dataReceived()
 {
+    if (!m_socket->canReadLine() && m_socket->bytesAvailable() > MAX_PACKET_SIZE) {
+        qCWarning(KDECONNECT_CORE) << "Discarding packet that's too large";
+        m_socket->readAll();
+    }
     while (m_socket->canReadLine()) {
         const QByteArray serializedPacket = m_socket->readLine();
         NetworkPacket packet;
-        NetworkPacket::unserialize(serializedPacket, &packet);
+        bool success = NetworkPacket::unserialize(serializedPacket, &packet);
+        if (!success) {
+            // unserialize already logs
+            continue;
+        }
 
         // qCDebug(KDECONNECT_CORE) << "LanDeviceLink dataReceived" << serializedPacket;
 
