@@ -7,17 +7,12 @@
 #ifndef LANLINKPROVIDER_H
 #define LANLINKPROVIDER_H
 
+#include <QNetworkInformation>
 #include <QObject>
 #include <QSslSocket>
 #include <QTcpServer>
 #include <QTimer>
 #include <QUdpSocket>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QNetworkConfigurationManager>
-#include <QNetworkSession>
-#else
-#include <QNetworkInformation>
-#endif
 
 #include "backends/linkprovider.h"
 #include "kdeconnectcore_export.h"
@@ -35,7 +30,7 @@ public:
     /**
      * @param testMode Some special overrides needed while testing
      */
-    LanLinkProvider(bool testMode = false);
+    LanLinkProvider(bool testMode = false, bool disabled = false);
     ~LanLinkProvider() override;
 
     QString name() override
@@ -48,6 +43,9 @@ public:
         return 20;
     }
 
+    void enable() override;
+    void disable() override;
+
     void sendUdpIdentityPacket(const QList<QHostAddress> &addresses);
 
     static void configureSslSocket(QSslSocket *socket, const QString &deviceId, bool isDeviceTrusted);
@@ -81,6 +79,7 @@ private:
     QList<QHostAddress> getBroadcastAddresses();
     void sendUdpIdentityPacket(QUdpSocket &socket, const QList<QHostAddress> &addresses);
     void broadcastUdpIdentityPacket();
+    bool isProtocolDowngrade(const QString &deviceId, int protocolVersion) const;
 
     Server *m_server;
     QUdpSocket m_udpSocket;
@@ -97,6 +96,8 @@ private:
     const bool m_testMode;
     QTimer m_combineNetworkChangeTimer;
 
+    bool m_disabled;
+
 #ifdef KDECONNECT_MDNS
     MdnsDiscovery m_mdnsDiscovery;
 #endif
