@@ -9,9 +9,12 @@
 #include <KPluginFactory>
 
 #include <QDebug>
+#include <QStandardPaths>
 
 #include <core/device.h>
+#include <filetransferjob.h>
 
+#include "albumart_cache.h"
 #include "plugin_mprisremote_debug.h"
 
 K_PLUGIN_CLASS_WITH_JSON(MprisRemotePlugin, "kdeconnect_mprisremote.json")
@@ -21,6 +24,11 @@ void MprisRemotePlugin::receivePacket(const NetworkPacket &np)
     if (np.type() != PACKET_TYPE_MPRIS)
         return;
 
+    if (np.get<bool>(QStringLiteral("transferringAlbumArt"), false)) {
+        AlbumArtCache::instance()->handleAlbumArt(np);
+        return;
+    }
+
     if (np.has(QStringLiteral("player"))) {
         const QString player = np.get<QString>(QStringLiteral("player"));
         if (!m_players.contains(player)) {
@@ -83,6 +91,13 @@ void MprisRemotePlugin::requestPlayerList()
     sendPacket(np);
 }
 
+void MprisRemotePlugin::requestAlbumArt(const QString &player, const QString &album_art_url)
+{
+    NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {{QStringLiteral("player"), player}, {QStringLiteral("albumArtUrl"), album_art_url}});
+    qInfo(KDECONNECT_PLUGIN_MPRISREMOTE) << "Requesting album art " << np.serialize();
+    sendPacket(np);
+}
+
 void MprisRemotePlugin::sendAction(const QString &action)
 {
     NetworkPacket np(PACKET_TYPE_MPRIS_REQUEST, {{QStringLiteral("player"), m_currentPlayer}, {QStringLiteral("action"), action}});
